@@ -2,12 +2,12 @@ package RPC::ExtDirect::Server::Foo;
 
 use base 'RPC::ExtDirect::Server';
 
-our $server_started;
+our $server_class;
 
 sub new {
     my ($class, %params) = @_;
 
-    $server_started = 1;
+    $server_class = $class;
 
     return $class->SUPER::new(%params);
 }
